@@ -1,6 +1,5 @@
-
 class SystemActions:
-    def __init__(self, britive):
+    def __init__(self, britive) -> None:
         self.britive = britive
         self.base_url = f'{self.britive.base_url}/v1/policy-admin/actions'
 
@@ -16,5 +15,3 @@ class SystemActions:
         if consumer:
             params['filter'] = f'consumer eq {consumer}'
         return self.britive.get(self.base_url, params=params)['result']
-
-
