@@ -1,6 +1,5 @@
-
 class SystemConsumers:
-    def __init__(self, britive):
+    def __init__(self, britive) -> None:
         self.britive = britive
         self.base_url = f'{self.britive.base_url}/v1/policy-admin/consumers'
 
@@ -12,5 +11,3 @@ class SystemConsumers:
         """
 
         return self.britive.get(self.base_url)['result']
-
-
